/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2011, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.jboss.test.marshalling;

import java.util.ArrayDeque;
import java.util.Iterator;

/**
 * @author <a href="mailto:david.lloyd@redhat.com">David M. Lloyd</a>
 */
public final class EqualableArrayDeque<X> extends ArrayDeque<X> {

    private static final long serialVersionUID = 5029699446105430182L;

    public boolean equals(final Object obj) {
        return obj instanceof EqualableArrayDeque && equals((EqualableArrayDeque<?>)obj);
    }

    public boolean equals(final EqualableArrayDeque<?> obj) {
        Iterator<X> i1 = iterator();
        Iterator<?> i2 = obj.iterator();
        while (i1.hasNext() && i2.hasNext()) {
            X o1 = i1.next();
            Object o2 = i2.next();
            if (o1 == null ? o2 != null : ! o1.equals(o2)) {
                return false;
            }
        }
        return i1.hasNext() == i2.hasNext();
    }
}
